@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Dict
 
 from pydantic import BaseModel
 
@@ -46,7 +46,7 @@ class Company(IngestedDataType):
     enrichment: Optional[CompanyEnrichment] = None
 
     @staticmethod
-    def from_pdl(pdl_input: dict[str, any]) -> Optional['Company']:
+    def from_pdl(pdl_input: Dict[str, any]) -> Optional['Company']:
         name = pdl_input.get('name')
         linkedin_internal_id = pdl_input.get('linkedin_id')
         if not name or not linkedin_internal_id:
